@@ -1,12 +1,12 @@
 <?php
-
-
+// $Id: index.php,v 1.99 2009/10/15 14:07:25 dries Exp $
+// add for plamo linux package
 if ( file_exists("install.php") ) {
   echo "<font color='red'>1.) Please access '<a href='install.php'>install.php</a>' for initial installation!  (You should make sure your mail server working before the installation.)</a></font><br />\n";
   echo "<font color='red'>2.) Please remove 'install.php' after the installation to start setup your site!</font><br />\n";
 }
-
 //for php-5.3// error_reporting(E_ALL & ~E_DEPRECATED);
+//
 
 /**
  * @file
@@ -19,28 +19,11 @@ if ( file_exists("install.php") ) {
  * See COPYRIGHT.txt and LICENSE.txt.
  */
 
-require_once './includes/bootstrap.inc';
+/**
+ * Root directory of Drupal installation.
+ */
+define('DRUPAL_ROOT', getcwd());
+
+require_once DRUPAL_ROOT . '/includes/bootstrap.inc';
 drupal_bootstrap(DRUPAL_BOOTSTRAP_FULL);
-
-$return = menu_execute_active_handler();
-
-// Menu status constants are integers; page content is a string.
-if (is_int($return)) {
-  switch ($return) {
-    case MENU_NOT_FOUND:
-      drupal_not_found();
-      break;
-    case MENU_ACCESS_DENIED:
-      drupal_access_denied();
-      break;
-    case MENU_SITE_OFFLINE:
-      drupal_site_offline();
-      break;
-  }
-}
-elseif (isset($return)) {
-  // Print any value (including an empty string) except NULL or undefined:
-  print theme('page', $return);
-}
-
-drupal_page_footer();
+menu_execute_active_handler();
