@@ -1,44 +1,53 @@
 #!/bin/bash
-# Drupal	(http://drupal.org)
+# Drupal7	(http://drupal.org)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-28
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-03
 # require:
 #	httpd-2.2.x
-#	php-5.2.x
+#	php-5.3.x
 #	postgresql-8.4.x
 #
 
+DRUSH_URI=http://ftp.drupal.org/files/projects/drush-7.x-4.4.tar.gz
+DRUSH_FILE=${SRC_URI##*/}
 
-wget -N http://ftp.drupal.org/files/projects/drush-All-Versions-HEAD.tar.gz
-tar xvfz drush-All-Versions-HEAD.tar.gz 
+if [ ! -f $DRUSH_FILE ]; then
+  wget -N $DRUSH_URI
+  tar xfz $DRUSH_FILE
+fi
 
 export PATH=/opt/php5/bin:$PATH
 
-#./drush/drush dl drupal > drush-dl-drupal.log
-#VERSION=`head -1 drush-dl-drupal.log | sed -e s'/.*(\(.*\)).*/\1/'`
+if [ ! -d drupal-7.0 ]; then
+  ./drush/drush dl drupal >& drush-dl-drupal.log
+  VERSION=`grep "Project drupal" drush-dl-drupal.log | sed -e s'/.*(\(.*\)).*/\1/'`
+else
+  VERSION=7.0
+fi
+echo "VERSION = $VERSION"
 
-VERSION=6.22
 PAC_NAME=drupal-$VERSION
-SRC_NAME=${PAC_NAME}.tar.gz
-SRC_URI=http://ftp.drupal.org/files/projects/${SRC_NAME}
-wget -N $SRC_URI
-tar xvfz $SRC_NAME
+echo "PAC_NAME = $PAC_NAME"
 
-(cd $PAC_NAME; ../drush/drush dl ja > drush-dl-ja.log)
-JVERS=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-ja.log`
+#(cd $PAC_NAME; ../drush/drush dl ja > drush-dl-ja.log)
+#JVERS=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-ja.log`
+#echo "JVERS = $JVERS"
 
-SRC_FILE=${PAC_NAME}-japanese_${JVERS}.tar.gz
+(cd $PAC_NAME/profiles/standard/translations/; \
+ wget -N http://ftp.drupal.org/files/translations/7.x/drupal/drupal-7.0.ja.po )
+
+SRC_FILE=${PAC_NAME}.tar.gz
 echo $SRC_FILE
 tar cvfz $SRC_FILE $PAC_NAME
 
-JAM_URI=http://downloads.sourceforge.net/drupal-jp/jamail-6.x-1.0.tgz
-JAM_FILE=${JAM_URI##*/}
+#JAM_URI=http://downloads.sourceforge.net/drupal-jp/jamail-6.x-1.0.tgz
+#JAM_FILE=${JAM_URI##*/}
 # using git:# git  clone  git://github.com/juk/drupal-tsearch.git
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/www/php/appli
 PAC_DIR=$PLAMO/Packages/4.7/09_webdb/03_PHP.tgz
-BUILD_DIR=$PLAMO/drupal6
+BUILD_DIR=$PLAMO/drupal7
 CUSTOM_DIR=$BUILD_DIR/Custom
 
 #( cd $CUSTOM_DIR; 
@@ -57,7 +66,7 @@ rm -rf $WORK/*
 mkdir -p  $WORK
 export LANG=C
 export CFLAGS="-O2"
-export PATH=$PATH:/usr/X11R6/bin
+export PATH=$PATH:/usr/X11R7/bin
 
 echo $PAC_DIR
 if [ ! -d $PAC_DIR ]; then
@@ -75,8 +84,8 @@ if [ ! -f $SRC_DIR/$JAM_FILE ]; then
   ( cd $SRC_DIR; wget $JAM_URI )
 fi 
 
-( cd $CUSTOM_DIR; 
-  git clone git://github.com/juk/drupal-tsearch.git )
+#( cd $CUSTOM_DIR; 
+#  git clone git://github.com/juk/drupal-tsearch.git )
 
 SHR_DIR=usr/share/
 mkdir -p $WORK/$SHR_DIR | exit
@@ -107,29 +116,28 @@ fi
 # insert installtion notation into index.php
 head -2 index.php > index.php.new
 cat >>index.php.new<<EOF
-
+// add for plamo linux package
 if ( file_exists("install.php") ) {
   echo "<font color='red'>1.) Please access '<a href='install.php'>install.php</a>' for initial installation!  (You should make sure your mail server working before the installation.)</a></font><br />\n";
   echo "<font color='red'>2.) Please remove 'install.php' after the installation to start setup your site!</font><br />\n";
 }
-
 //for php-5.3// error_reporting(E_ALL & ~E_DEPRECATED);
-
+//
 EOF
 sed -e '1,2d' index.php >> index.php.new
 mv  index.php.new  index.php
 
 
-mkdir -p files
-mkdir -p sites/all/themes
-mkdir -p sites/all/modules
-(cd sites/all/modules; tar xvfz $SRC_DIR/$JAM_FILE)
-(cd sites/all/modules;
-  mkdir tsearch;  cp $CUSTOM_DIR/drupal-tsearch/* tsearch/;
-  patch tsearch/tsearch.install $CUSTOM_DIR/tsearch.install-pg8.4.patch;
-# tar xfz $CUSTOM_DIR/$TS2_FILE;
-#  mv $TS2_DIR tsearch;
-)
+mkdir -p sites/default/files
+#mkdir -p sites/all/themes
+#mkdir -p sites/all/modules
+#(cd sites/all/modules; tar xvfz $SRC_DIR/$JAM_FILE)
+#(cd sites/all/modules;
+#  mkdir tsearch;  cp $CUSTOM_DIR/drupal-tsearch/* tsearch/;
+#  patch tsearch/tsearch.install $CUSTOM_DIR/tsearch.install-pg8.4.patch;
+## tar xfz $CUSTOM_DIR/$TS2_FILE;
+##  mv $TS2_DIR tsearch;
+#)
 
 
 DOC_DIR=usr/share/doc/$PAC_NAME
@@ -152,7 +160,7 @@ TYP	$TYP
 NAM	${PAC_NAME}
 URL	http://drupal.org/
 DOC	/${DOC_DIR}/
-EXE	/drupal6/
+EXE	/drupal7/
 REM	content management platform(blog etc.)
 __EOCL__
 
